@@ -10,11 +10,13 @@ FUNDAMENTAL_CRITERIA = [
     "category",
     "variant_type",
     "hgnc_symbols",
+    "repids",
     "gene_panels",
     "chrom",
     "start",
     "end",
     "variant_ids",
+    "hide_dismissed",
 ]
 
 # If there is only one primary criterion given without any secondary, it will also be
