@@ -6,9 +6,8 @@ EXPORT_HEADER = [
     "Position_Change",
     "HGNC_id",
     "Gene_name",
-    "Canonical_transcript",
-    "Canonical_transcript_HGVS",
-    "Canonical_transcript_protein_change",
+    "Canonical_transcript/HGVS/protein_change",
+    "Primary_transcript/HGVS/protein_change",
 ]
 
 MT_EXPORT_HEADER = [
