@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 import datetime
-from scout.server.extensions import store
+
+from flask import get_template_attribute, url_for
 from pymongo import ReturnDocument
-from flask import url_for, get_template_attribute
+
+from scout.server.extensions import store
 
 
 def test_report_transcripts_macro(app, institute_obj, case_obj, variant_gene_updated_info):
