@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
-import pymongo
-from flask import url_for, current_app
-from flask_login import current_user
 from urllib.parse import urlencode
+
+import pymongo
+from flask import current_app, url_for
+from flask_login import current_user
+
 from scout.server.extensions import store
 
 
@@ -131,8 +133,11 @@ def test_bulk_reset_dismiss_variants(app, institute_obj, case_obj):
         updated_variant = store.variant_collection.find_one({"_id": variant["_id"]})
         assert updated_variant.get("dismiss_variant") is None
 
-        # And 2 relative events should be found in the database
-        assert sum(1 for i in store.event_collection.find()) == 2
+        # 2 variant-relative events should be found in the database
+        assert sum(1 for i in store.event_collection.find({"category": "variant"})) == 2
+
+        # And one case-specifuc event should also be created
+        assert sum(1 for i in store.event_collection.find({"category": "case"})) == 1
 
 
 def test_variants_research(app, institute_obj, case_obj):
